<div align="center">

# Ayaka小游戏合集 - 0.0.5b0

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/ayaka_games)
![PyPI - Downloads](https://img.shields.io/pypi/dm/ayaka_games)
![PyPI - License](https://img.shields.io/pypi/l/ayaka_games)
![PyPI](https://img.shields.io/pypi/v/ayaka_games)

开发进度 10/10

**特别感谢**  [@灯夜](https://github.com/lunexnocty/Meiri) 大佬的印加宝藏

</div>

得益于[ayaka](https://github.com/bridgeL/ayaka)，本插件可作为如下机器人框架的插件使用

- [nonebot2](https://github.com/nonebot/nonebot2)(使用[onebot11](https://github.com/nonebot/adapter-onebot)适配器)
- [hoshino](https://github.com/Ice-Cirno/HoshinoBot)
- [nonebot1](https://github.com/nonebot/nonebot)

也可将其作为console程序离线运行

## 文档

https://bridgel.github.io/ayaka_games/

## 其他

本插件的前身：[nonebot_plugin_ayaka_games](https://github.com/bridgeL/nonebot-plugin-ayaka-games)
